==> haskell-bz2-1.0.1.1-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bz2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bz2
version:              1.0.1.1
visibility:           public
id:                   bz2-1.0.1.1-LB0GI0KNoIB5CEyVm2BkPv
key:                  bz2-1.0.1.1-LB0GI0KNoIB5CEyVm2BkPv
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  83b4d83cc8b8f2cc2ce0c886c50c366e
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Common Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Unpack Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bz2
hs-libraries:         HSbz2-1.0.1.1-LB0GI0KNoIB5CEyVm2BkPv
extra-libraries:      bz2
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bz2-1.0.1.1-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bz2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bz2
version:              1.0.1.1
visibility:           public
id:                   bz2-1.0.1.1-GKTUIwjJEADFYtMuZWiWp6
key:                  bz2-1.0.1.1-GKTUIwjJEADFYtMuZWiWp6
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  3c6f8cdfa73ce524d2d1f5a95cb15ca9
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Common Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Unpack Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bz2-1.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bz2
hs-libraries:         HSbz2-1.0.1.1-GKTUIwjJEADFYtMuZWiWp6
extra-libraries:      bz2
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
